##  AUTOMATION_TRIGGERED

```
{
  "tag": "AUTOMATION_WEBHOOK_TAG",
  "userId": "6ef78c21-98a2-4377-acaa-fc66ff2b78gf",
  "factSheet": {
    "id": "7a5bace3-4f7c-4682-b511-aecc9a6927d0",
    "type": "Application",
    "displayName": "Test Application Fact Sheet"
  },
  "automation": {
    "id": "3c72aa45-457a-4c10-9fac-40146121167c",
    "sourceUrl": "https://app.leanix.net/workspace-name/admin/automations/edit/3c72aa45-457a-4c10-9fac-40146121167c"
  },
  "workspaceId": "b7d655f1-4aa0-4132-92c6-a390a60cb8gh"
}
```



